;
(function ($) {
    /**
     *  扁平按钮控件
     *
     *     @example
     *     var btn = new FR.OldButton({
     *             renderEl : $('body'),
     *             text : "OldButton",
     *             hotKeys : "enter",
     *             iconCls : "custom-btn-blue",
     *             iconAlign : "right",
     *             scale : "medium",
     *             handler : function(){alert("click me")}
     *     });
     * @class FR.OldButton
     * @extends FR.Button
     *
     * @cfg {String} text 按钮上的文字
     * @cfg {String} hotKeys 触发按钮的快捷键
     * @cfg {String} iconCls 按钮的css样式表类
     * @cfg {"right"|"left"|"top"|"bottom"} [iconAlign="right"] 按钮图标的对齐方式
     * @cfg {"small"|"medium"|"large"} [scale="medium"] 按钮的尺寸
     * @cfg {Function} handler 点击按钮时触发的事件
     */
    FR.OldButton = FR.extend(FR.Button, /**@class FR.OldButton */{

        /**
         * 初始化按钮的dom结构
         * @param o 配置属性
         * @private
         */
        initTable: function (o) {
            if (!o.text && o.value) {
                o.text = o.value;
            }
            // 有边框的情况下，不应该直接用当前td的高度画button，这样的话加上边框就比实际的要高一像素，
            // 会把父元素的tr撑高一像素，一般不会有问题，但是设置了冻结的话不在一个TABLE中就会错位,bug32012
            if (o.border) {
                if (o.border.bottom === 1 || o.border.top === 1) {
                    o.height = o.height - 1;
                }
                if (o.border.right === 1 || o.border.left === 1) {
                    o.width = o.width - 1;
                }
            }
            var id = o.baseCls + "-" + o.widgetName;
            var cls = (o.icon)
                ? (o.text ? ' fr-btn-text-icon-old' : ' fr-btn-icon-old')
                : ' fr-btn-noicon-old';
            var size = 'width:' + o.width + "px;height:" + o.height + "px";
            var scaleCls = 'fr-btn-' + o.scale + ' fr-btn-icon-' + o.scale + '-'
                + o.iconAlign;
            var config = {"id": id, "cls": cls, "size": size, "scaleCls": scaleCls, "btnText": o.text, "height": o.height, "icon": o.icon, "width": o.width, "borderWidth": o.borderWidth};
            // 生成btn
            this.$table = FR.Button.CacheTable.get(config);
            this.$table.appendTo(this.element);
            this.$btn = this.$table.$btn;
            FR.Button.setMaxWidth(this.$btn, config);
            this.centertr = this.$table.centertr;
            // ie6 冻结 带边框 btn 高度过小 对不齐 直接隐藏了
            // 704及以前的button高度为18，ie下隐藏的话，会显示不全
            if ($.browser.msie && o.height < 18) {
                $('tr:eq(0)', this.$table).hide();
                $('tr:eq(2)', this.$table).hide();
            }

        },
        addEvents: function (o) {
            if (!this.$table) {
                return;
            }
            var self = this;
            var M = {
                onMouseOver: function () {
                    if (self.isEnabled()) {
                        self.$table.addClass(o.baseCls + "-over-old");
                    }
                },
                onMouseOut: function () {
                    if (self.isEnabled()) {
                        self.$table.removeClass(o.baseCls + "-over-old");
                        self.$table.removeClass(o.baseCls + "-click-old");
                    }
                },
                onMouseDown: function () {
                    if (self.isEnabled()) {
                        self.$table.addClass(o.baseCls + "-click-old");
                        self.$table.removeClass(o.baseCls + "-over-old");
                        $(document).bind("mouseup", M.onMouseUp);
                    }
                },
                onMouseUp: function () {
                    if (self.isEnabled()) {
                        self.$table.removeClass(o.baseCls + "-click-old");
                        self.$table.addClass(o.baseCls + "-over-old");
                        $(document).unbind("mouseup", M.onMouseUp);
                    }
                }
            }
            this.$table.mouseover(M.onMouseOver.createInterceptor(this.isEnabled(), this))
                .mouseout(M.onMouseOut)
                .mousedown(M.onMouseDown.createInterceptor(this.isEnabled(), this))
                .mouseup(M.onMouseUp);
            this.$table.keydown(function (e) {
                if (e.keyCode === 13) {
                    e.stopPropagation();
                }
            });
            this.$table.click(function (e) {
                if (self.isEnabled()) {
                    self.fireEvent(FR.Events.CLICK, e);
                }
            });
        },
        setEnable: function (enabled) {
            FR.Button.superclass.setEnable.apply(this, arguments);
            var clz = this.options.baseCls;
            if (this.$table && enabled === false) {
                this.$table.removeClass(clz + "-over-old")
                    .removeClass(clz + "-click-old");
            }
        },
        doResize: function (give) {
            FR.Button.superclass.doResize.call(this, give);
            var width = give ? give.width : this.options.width;
            var height = give ? give.height : this.options.height;
            this.$table.css({
                width: width,
                height: height
            });
            this.setMaxWidth(width);
        },
        getType: function () {
            return 'button';
        }
    });
    $.shortcut("oldbutton", FR.OldButton);
    //hiram_write: Button中的table创建比较耗时，且样式几乎都是一样的
//这里缓存了Button中创建过的表格样式,返回clone的对象。
    FR.Button.CacheTable = {
        tables: [],
        keyAttrs: ["id", "cls", "size", "scaleCls", "btnText", "height", "icon", "width", "borderWidth"],
        _getPrototypeTable: function (key) {
            for (var i = this.tables.length - 1; i >= 0; i--) {
                if (this.campare(key, this.tables[i].key)) {
                    return this.tables[i].value;
                }
            }
            var table = FR.Button.createTable(key);
            this.tables.push({"key": key, "value": table});
            return table;
        },
        get: function (key) {
            var table = this._getPrototypeTable(key);
            return this.clone(table);
        },
        campare: function (key, key2) {
            for (var i = 0; i < this.keyAttrs.length; i++) {
                var attr = this.keyAttrs[i];
                if (key[attr] != key2[attr]) {
                    return false;
                }
            }
            return true;
        },
        clone: function (value) {
            var ret = value.clone(true);
            var $btn = $("button", ret);
            $btn.isSetWidth = value.$btn.isSetWidth;
            ret.centertr = value.centertr;
            ret.$btn = $btn;
            return ret;
        }
    };

    FR.Button.createTable = function (config) {
        var btnStrArr = [
            "<table id='",
            config.id,
            "' cellspacing='0' class='fr-btn ",
            config.cls,
            "' style='",
            config.size,
            "'>",
            "<tbody class='",
            config.scaleCls,
            "'>",
            "<tr><td class='fr-btn-tl'><i>&#160;</i></td><td class='fr-btn-tc'></td><td class='fr-btn-tr'><i>&#160;</i></td></tr>",
            "<tr><td class='fr-btn-ml'><i>&#160;</i></td><td class='fr-btn-mc'><em unselectable='on'><button data-role='none' type='button' class='fr-btn-text'>",
            config.btnText,
            "</button></em></td><td class='fr-btn-mr'><i>&#160;</i></td></tr>",
            "<tr><td class='fr-btn-bl'><i>&#160;</i></td><td class='fr-btn-bc'></td><td class='fr-btn-br'><i>&#160;</i></td></tr>",
            "</tbody></table>"];
        var $table = $(btnStrArr.join(""));
        var $btn = $("button", $table);
        var centertr = $('tr:eq(1)', $table);
        $table.$btn = $btn;
        $table.centertr = centertr;
        FR.Button.setIcon($table.$btn, config.icon);
        $('tr:eq(0)', $table).height(3);
        $('tr:eq(2)', $table).height(3);

        return $table;
    };
})(jQuery);
;
(function ($) {
    /**
     * 扁平复选框
     *
     *     @example
     *     var editor = new FR.OldCheckBox({
     *              renderEl : 'body',
     *              text : "是否显示实际值",
     *              selected : true,     //是否被选中
     *              disabled : false     //状态是否可变
     *     });
     *
     * @class FR.OldCheckBox
     * @extends FR.CheckBox
     */
    FR.OldCheckBox = FR.extend(FR.CheckBox, /**@class FR.OldCheckBox */{
        selected_class: 'fr-checkbox-old-checkon',
        unselected_class: 'fr-checkbox-old-checkoff',
        getType: function () {
            return 'checkbox';
        }

    });
    $.shortcut('oldcheckbox', FR.OldCheckBox);
})(jQuery);


;
(function ($) {
    /**
     * 扁平的单选按钮
     *
     *     @example
     *     var editor = new FR.OldRadioButton({
     *          renderEl : 'body',
     *          text : "默认选中",
     *          selected : true,
     *          disabled : false
     *     });
     *
     * @class FR.OldRadioButton
     * @extends FR.RadioButton
     */

    FR.OldRadioButton = FR.extend(FR.RadioButton, /**@class FR.OldRadioButton */{
        selected_class: 'fr-radio-old-radioon',
        unselected_class:'fr-radio-old-radiooff',
        getType: function () {
            return 'radio';
        }
    });
    $.shortcut('oldradio', FR.OldRadioButton);
})(jQuery);


;
(function ($) {
    /**
     * 扁平的参数查询控件
     * @class FR.OldFormSubmitButton
     */
    FR.OldFormSubmitButton = FR.extend(FR.OldButton, {
        _init: function () {
            FR.FormSubmitButton.superclass._init.apply(this, arguments);
        },
        getType: function () {
            return 'formsubmit';
        }

    });
    $.shortcut('oldformsubmit', FR.OldFormSubmitButton);
})(jQuery);


;
(function ($) {
    /**
     * 扁平的菜单按钮
     * @class FR.MenuButton
     * @extends FR.Button
     */
    FR.OldMenuButton = FR.extend(FR.OldButton, {
        _init: function () {
            FR.MenuButton.superclass._init.apply(this, arguments);
            if(this.$table){
                this.$table.children('tbody').children('tr').children('td')
                    .children('em').addClass('fr-btn-arrow');
            }

            /*
             * alex:如果menu是一个数组的话,当click时弹出菜单 以后可以支持hover的时候就弹出
             */
            var menu = this.options.menu;
            if (FR.isArray(menu)) {
                this.on("click", function () {
                    FR.showMenuByEl({
                        destroyOnClose: true,
                        items: menu,
                        minWidth: 175,
                        xxxfixclientH: this.options.istoolbarmenu
                            ? true
                            : false
                    }, this.element)
                }.createDelegate(this));
                if( this.$table){
                    this.$table.mouseleave(function (e) {
                        if (this.fr_menu) {
                            var bounds = {
                                x: this.fr_menu.menu.$menuRoot.offset().left,
                                y: this.fr_menu.menu.$menuRoot.offset().top
                                - 1,
                                width: this.fr_menu.menu.$menuRoot.bounds().width,
                                height: this.fr_menu.menu.$menuRoot.bounds().height
                            };
                            if (e.clientY < bounds.y
                                || e.clientY > bounds.y + bounds.height
                                || e.clientX < bounds.x
                                || e.clientX > bounds.x + bounds.width) {
                                this.fr_menu.menu.close();
                            }
                        }
                    }.createDelegate(this.element));
                }
            }
        },
        getType: function () {
            return 'menubutton';
        }
    });

    $.shortcut('oldmenubutton', FR.OldMenuButton);
})(jQuery);