;
(function ($) {
    /**
     * 复选按钮组。一系列的复选按钮组成的控件，可以选择其中的零个或者多个。
     *
     *     @example
     *     var editor = new FR.OldCheckBoxGroup({
     *          renderEl : 'body',
     *          width : 200,
     *          height : 100,
     *          columnsInRow : 1,
     *          mode : 'local',
     *          items : [
     *              {text : 'apple', value : '1'},
     *              {text : 'orange', value : '2'},
     *              {text : 'banana', value : '3'}
     *          ]
     *     });
     *
     * @class FR.OldCheckBoxGroup
     * @extends FR.CheckBoxGroup
     *
     * @cfg {JSON} o 配置属性
     * @cfg {Boolean} [o.adaptive=false] 是否自使用宽度换行，如果为true，将自动计算每行放置多少个子控件
     * @cfg {Number} [o.columnsInRow=0] 每行包含子控件的个数，0表示只有一行，全部子控件都在这一行里面
     * @cfg {String} [o.delimiter=','] 返回值的分隔符，当控件返回多个值是，以指定的分隔符将每个值连接起来
     * @cfg {String} [o.startSymbol=''] 返回值的起始补充符，默认为空
     * @cfg {String} [o.endSymbol=''] 返回值的结束补充符，默认为空
     */
    FR.OldCheckBoxGroup = FR.extend(FR.CheckBoxGroup, /**@class FR.OldCheckBoxGroup */{

        initItemBox:function(idx, it,outter){
            return  new FR.OldCheckBox({
                renderEl: $("<div/>").appendTo(outter),
                disabled: this.options.disabled,
                text: it.getShowValue(),
                fieldValue: it.getValue(),
                sessionID: this.options.sessionID,
                widgetName: this.options.widgetName,
                fontSize: this.options.fontSize
            });
        },
        getSelectedItems:function(){
            return $('.fr-checkbox-old-checkon', this.$container);
        },
        getType: function () {
            return 'checkboxgroup';
        }
    });
    $.shortcut('oldcheckboxgroup', FR.OldCheckBoxGroup);
})(jQuery);

;
(function ($) {
    /**
     * 单选按钮组
     *
     *     @example
     *     var editor = new FR.OldRadioGroup({
     *          renderEl : 'body',
     *          width : 200,
     *          height : 100,
     *          columnsInRow : 3,       //一行能显示的个数
     *          items : [
     *                  {text : '111', value : '1'},
     *                  {text : '222', value : '2'},
     *                  {text : '333', value : '3'},
     *                  {text : '444', value : '4'},
     *                  {text : '555', value : '5'},
     *                  {text : '666', value : '6'}
     *          ]
     *     });
     *
     * @class FR.OldRadioGroup
     * @extends FR.RadioGroup
     *
     * @cgf {JSON} o 配置属性
     * @cfg {Boolean} [o.adaptive=false] 是否自使用宽度换行，如果为true，将自动计算每行放置多少个子控件
     * @cfg {Number} [o.columnsInRow=0] 每行包含子控件的个数，0表示只有一行，全部子控件都在这一行里面
     */
    FR.OldRadioGroup = FR.extend(FR.RadioGroup, /**@class FR.OldRadioGroup */{

        initItemRadio: function(idx,it,outter,rname){
            return new FR.OldRadioButton({
                renderEl: $("<div/>").appendTo(outter),
                disabled: this.options.disabled,
                text: it.getShowValue(),
                fieldValue: it.getValue(),
                sessionID: this.options.sessionID,
                name: rname,
                fontSize: this.options.fontSize
            });
        },
        getType: function () {
            return 'radiogroup';
        }
    });
    $.shortcut('oldradiogroup', FR.OldRadioGroup);
})(jQuery);